# Filename: 247sock_needles.awk
#
## Last update: Tue Aug  5 07:53:47 2008 by Rob Macleod
#    - created
#
# Make the mux mapping file for the combo of
# Bank #1: 247-lead sock and 9 leads grounded
# Bank #2: N needles ( N*10 channels) and 256 - N*10 grounded
#
# Usage: awk -f 247sock_needles.awk numneedles=N full=1/0 tempfile
#
# where   numneedles = the number of needles in the second bank
#         full = 1 for a full mux mapping file for the acquistion program
#              = 0 for mux mapping of just the useful leads.
#	  tempfile = file name of a file that contains the mux mode value
#                      (single = 512 channels or double = 1024 channels)
# 
######################################################################
BEGIN{
    numsock=247;
    numperneedle=10;
    numchans=0;
}
/single/{
# First the 247 lead sock: 1, 3, 5, 7, 9...
    if ( full == 1 ) {
	printf("512 channels\n");
    } else {
	printf("%d channels\n", numsock);
    }
    for (lnum=0; lnum < numsock; lnum++) {
	printf("%4d ", lnum*2 + 1);
	numchans++;
	if ( numchans % 8 == 0 ){
	    printf("\n");
	}
    }
    printf("Wrote %d channels of sock\n", numchans) > "/dev/tty";

# Now the needles: 2, 4, 6, 8, 10, ...
    for (nnum=0; nnum < numneedles; nnum++) {
	for (elnum=0; elnum < numperneedle; elnum++) {
	    printf("%4d ", nnum * numperneedle * 2 + elnum*2 + 2);
	    numchans++;
	    numneedlechans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
    }
    printf("Wrote %d channels of needles\n", numneedlechans) > "/dev/tty";

# Now the fill at the end of the file to make up the full 512 channels

    if ( full == 1 ) {
	for (lnum=numsock; lnum < 256; lnum++) {
	    printf("%4d ", lnum*2 + 1);
	    numchans++;
	    numfillchans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
	for (lnum=numneedles * numperneedle; lnum < 256; lnum++) {
	    printf("%4d ", lnum*2 + 2);
	    numchans++;
	    numfillchans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
	printf("Wrote %d channels of end fill\n", numfillchans) > "/dev/tty";
    }

    printf("For a total of %d channels\n", numchans) > "/dev/tty";
    printf("\n");
}
/double/{

# First the 247 lead sock: 1, 5, 9, 13, 17....
    if ( full == 1 ) {
	printf("1024 channels\n");
    } else {
	printf("%d channels\n", numsock + numneedles * numperneedle);
    }
    for (lnum=0; lnum < numsock; lnum++) {
	printf("%4d ", lnum*4 + 1);
	numchans++;
	if ( numchans % 8 == 0 ){
	    printf("\n");
	}
    }
    printf("Wrote %d channels of sock\n", numchans) > "/dev/tty";

# Now the needles: 2, 6, 10, 14, ...1022, 4, 8, 12, ... 1024
    if ( numneedles * numperneedle <=256 ) {
	numneedles1 = numneedles;
	numneedles2 = 0;
    } else {
	numneedles1 = 25;
	numneedles2 = numneedles - 25;
    }
    for (nnum=0; nnum < numneedles1; nnum++) {
	for (elnum=0; elnum < numperneedle; elnum++) {
	    printf("%4d ", nnum * numperneedle * 4 + elnum*4 + 2);
	    numchans++;
	    numneedlechans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
    }
    for (nnum=0; nnum < numneedles2; nnum++) {
	for (elnum=0; elnum < numperneedle; elnum++) {
	    printf("%4d ", nnum * numperneedle * 4 + elnum*4 + 4);
	    numchans++;
	    numneedlechans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
    }
    printf("Wrote %d channels of needles\n", numneedlechans) > "/dev/tty";

# Now the fill at the end of the file to make up the full 1024 channels

    if ( full == 1 ) {
	for (lnum=numsock; lnum < 256; lnum++) {
	    printf("%4d ", lnum*4 + 1);
	    numchans++;
	    numfillchans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
	for (lnum=0; lnum < 256; lnum++) {
	    printf("%4d ", lnum*4 + 3);
	    numchans++;
	    numfillchans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
	for (lnum=numneedles1 * numperneedle; lnum < 256; lnum++) {
	    printf("%4d ", lnum*4 + 2);
	    numchans++;
	    numfillchans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
	for (lnum=numneedles2 * numperneedle; lnum < 256; lnum++) {
	    printf("%4d ", lnum*4 + 4);
	    numchans++;
	    numfillchans++;
	    if ( numchans % 8 == 0 ){
		printf("\n");
	    }
	}
	printf("Wrote %d channels of end fill\n", numfillchans) > "/dev/tty";
    }
    
    printf("For a total of %d channels\n", numchans) > "/dev/tty";
    printf("\n");

}
