#!/bin/sh
# A script to make a set of mapping files
#
# Useage: makemuxmapping.sh -m 512/1024 -t numtank -s numsock -n numneedles -f
#
## Last update: Sun Jun 25 22:03:37 2017 by Rob Macleod
##    - trying to rejuvenate this script...
# Last update: Mon Mar  3 20:31:53 2003 by Rob MacLeod
#    - added in support for endocardial sock leads
# Last update: Wed Jul 24 14:19:14 2002 by Rob MacLeod
#    - added needles only case and streamlined some of the
#      underlying scripts for needles
# Last update: Wed May 15 20:43:35 2002 by Rob MacLeod
#    - added case of more than 512 channel sock or cage
######################################################################
AWK=awk
AWKFILESOCK128=128sock_needles.awk
AWKFILESOCK247=247sock_needles.awk
AWKFILESOCK490=490sock_needles.awk
AWKFILEANDY3=andy3.awk
AWKFILENEEDLES=needles.awk

#AWKFILESOCK128=${ROBHOME}/torso/muxmapping/128sock_needles.awk
#AWKFILESOCK247=${ROBHOME}/torso/muxmapping/247sock_needles.awk
#AWKFILESOCK490=${ROBHOME}/torso/muxmapping/490sock_needles.awk
#AWKFILEANDY3=${ROBHOME}/torso/muxmapping/andy3.awk
#AWKFILENEEDLES=${ROBHOME}/torso/muxmapping/needles.awk
TEMPFILE=muxmapping.text

USAGE="\n Usage: makemuxmapping.sh -t numtank -s numsock -e numendosock 
         \t\t      -n numneedles -m 512/1024 -f
	 \t With:
	 \t -t to set number of tank electrodes
	 \t -s to set number of epicardial sock electrodes
	 \t -e to set number of endocardial sock electrodes
	 \t -n to set number of needles
         \t -m to set MUX config (512 or 1024 leads)
	 \t -f for a full mapping file (with padding)"
# Check input
if [ $# -lt 2 ]
  then
  echo "$USAGE"
  exit 1
fi
###################################################################
fullmap=""
numtankchans=0
numsockchans=0
numendochans=0
numneedles=0
nummuxchans=0

while getopts e:t:s:n:m:f optval
  do
  case $optval in
    t) numtankchans=$OPTARG;;
    s) numsockchans=$OPTARG;;
    e) numendochans=$OPTARG;;
    n) numneedles=$OPTARG;;
    m) nummuxchans=$OPTARG;;
    f) fullmap=t;;
    \?) echo $USAGE
    exit 2;;
  esac
done

if [ $nummuxchans = 512 ]
  then
  muxmode=single
elif [ $nummuxchans = 1024 ]
  then
  muxmode=double
else
  echo "We have to know how many mux channels there are, 512 or 1024"
  exit 1
fi

# Now call the program to make the mapping file
echo $muxmode >  $TEMPFILE

if [ "$fullmap" ]
  then
  full=1
else
  full=0
fi

# Build the filename string based on the input
filestring=""
if [ ${numtankchans} -gt 192 ]
  then
  filestring="_${numtankchans}t"
fi
if [ ${numsockchans} -gt 0 ]
  then
  filestring="${filestring}_${numsockchans}s"
fi
if [ ${numendochans} -gt 0 ]
  then
  filestring="${filestring}_${numendochans}e"
fi
if [ ${numneedles} -gt 0 ]
  then
  filestring="${filestring}_${numneedles}n"
fi
if [ $nummuxchans = 1024 ]
  then
  filestring="${filestring}_1024"
fi
if [ $full = 1 ]
  then
  filestring="${filestring}_full.mapping"
else
  filestring="${filestring}.mapping"
fi

# Loop through the major forks in the road.  Fore each of tank or sock
# included and needles only.

# Tank included

awkname=""
if [ $numtankchans -gt 0 ]
  then
  if [ $numtankchans -lt 375 ]
    then
    outfilename="andy3${filestring}"
    awkname=$AWKFILEANDY3
  else
    echo "Sorry, no method that accepts $numtankchans tank channels"
    exit -1
  fi

  # No tank but sock included
  
elif [ $numsockchans -gt 0 ]
  then
  if [ $numsockchans -eq 128 ]
    then
    outfilename="sock${filestring}"
    numtankleads=0
    awkname=$AWKFILESOCK128
  elif [ $numsockchans -eq 247 ]
    then
    outfilename="sock${filestring}"
    numtankleads=0
    awkname=$AWKFILESOCK247
  elif [ $numsockchans -eq 490 ]
    then
    outfilename="sock${filestring}"
    numtankleads=0
    awkname=$AWKFILESOCK490
  else
    echo "Sorry, no method when number of sock leads = $numsockchans"
  fi
  
  # Just needles
elif [ $numneedles -gt 0 ]
  then
  echo "Needles only"
  outfilename="needles${filestring}"
  numtankleads=0
  awkname=$AWKFILENEEDLES
  
else
  echo "Sorry, no script fore this combo"
  echo "Number of tank leads = $numtankchans"
  echo "Number of sock leads = $numsockchans"
  echo "Number of needles = $numneedles"
fi

# Make sure that the output file does not exist already.
if [ -w ${outfilename} ]
  then
  echo "\n\n The desired output file ${outfilename} already exists"
  echo " To overwrite is .............. o"
  echo " Or else exit here ............ return  ? \c"
  read inchar
  if [ "$inchar" = o ]
    then
    /bin/rm -f ${outfilename}
  else
    exit 1
  fi
fi

# Finally, run the awk script
if [ -n "$awkname" ]
  then
  echo "Running as $AWK -f $awkname numtankleads=$numtankchans\
  numsockleads=$numsockchans numendoleads=$numendochans \
  numneedles=$numneedles full=$full $TEMPFILE  > $outfilename"
  $AWK -f $awkname numtankleads=$numtankchans\
  numsockleads=$numsockchans numendoleads=$numendochans \
  numneedles=$numneedles full=$full $TEMPFILE  > $outfilename
  echo "Finished with $outfilename"
else
  echo "No program name found"
fi

# Clean up
/bin/rm $TEMPFILE

