# Filename: needles.awk
#
# Last update: Wed Jul 24 13:08:15 2002 by Rob MacLeod
#    - created
#
# Make the mux mapping file for the combo of
# Bank #1: up to 12 needle connectors with 2 needles each for 24 total
#          and the remaining 16 grounded
# Bank #2: remaining N needles with 256 - N*10 channels grounded
#
# Usage: awk -f needles.awk numneedles=N full=1/0 tempfile
#
# where   numneedles = total number of needles 
#         full = 1 for a full mux mapping file for the acquistion program
#              = 0 for mux mapping of just the useful leads.
#	  tempfile = file name of a file that contains the mux mode value
#                      (single = 512 channels or double = 1024 channels)
# 
######################################################################
BEGIN{
    numperneedle=10;
    numchans=0;
}
/single/{
    offset[1] = 1;
    offset[2] = 2;

# Load up the control arrays
    if ( numneedles > 24 ) {
	numinb[1] = 24;
	numinb[2] = numneedles - 24;
    } else {
	numinb[1] = numneedles;
	numinb[2] = 0;
    }

    if ( full == 1 ) {
	printf("512 channels\n");
    } else {
	printf("%d channels\n", numneedles * numperneedle);
    }

# Loop through all 2 banks

    for (bnum=1; bnum <= 2; bnum++ ){

	for (nnum=0; nnum < numinb[bnum]; nnum++) {
	    for (elnum=0; elnum < numperneedle; elnum++) {
		printf("%4d ", \
		       nnum * numperneedle * 2 + elnum*2 + offset[bnum]);
		numchans++;
		numneedlechans++;
		if ( numchans % 8 == 0 ){
		    printf("\n");
		}
	    }
	}

	printf("Bank %d contains %d channels from %d needles \n", \
	       bnum, numinb[bnum]*numperneedle, numinb[bnum]) > "/dev/tty";
    }
    printf("Wrote %d channels of needles\n", numneedlechans) > "/dev/tty";

# Now the fill at the end of the file to make up the full 512 channels

    if ( full == 1 ) {
	for ( bnum = 1; bnum <= 2; bnum++ ){
	    for (lnum=numinb[bnum] * numperneedle; lnum < 256; lnum++) {
		printf("%4d ", lnum*2 + offset[bnum]);
		numchans++;
		numfillchans++;
		if ( numchans % 8 == 0 ){
		    printf("\n");
		}
	    }
	}
	printf("Wrote %d channels of end fill\n", numfillchans) > "/dev/tty";
    }
    printf("For a total of %d channels\n", numchans) > "/dev/tty";
    printf("\n");
}

/double/{

    offset[1] = 1;
    offset[2] = 3;
    offset[3] = 2;
    offset[4] = 4;

    if ( full == 1 ) {
	printf("1024 channels\n");
    } else {
	printf("%d channels\n", numneedles * numperneedle);
    }
# Load up the control arrays
    if ( numneedles <= 24 ) {
	numinb[1] = numneedles;
	numinb[2] = numinb[3] = numinb[4] = 0;
    } else if ( numneedles <= 48 ) {
	numinb[1] = 24;
	numinb[2] = numneedles - 24;
	numinb[3] = numinb[4] = 0;
    } else if ( numneedles <= 72 ) {
	numinb[1] = numinb[2] = 24;
	numinb[3] = numneedles - 48;
	numinb[4] = 0;
    } else if ( numneedles <= 96 ) {
	numinb[1] = numinb[2] = numinb[3] = 24;
	numinb[4] = numneedles - 72;
    } else {
	printf("No support for %d needles\n", numneedles);
	exit;
    }

# Loop through all 4 banks

    for (bnum=1; bnum <= 4; bnum++ ){

	for (nnum=0; nnum < numinb[bnum]; nnum++) {
	    for (elnum=0; elnum < numperneedle; elnum++) {
		printf("%4d ", \
		       nnum * numperneedle * 4 + elnum*4 + offset[bnum]);
		numchans++;
		numneedlechans++;
		if ( numchans % 8 == 0 ){
		    printf("\n");
		}
	    }
	}

	printf("Bank %d contains %d channels from %d needles \n", \
	       bnum, numinb[bnum]*numperneedle, numinb[bnum]) > "/dev/tty";
    }
    printf("Wrote %d channels of needles\n", numneedlechans) > "/dev/tty";

# Now the fill at the end of the file to make up the full 1024 channels

    if ( full == 1 ) {
	for ( bnum = 1; bnum <= 4; bnum++ ){
	    for (lnum=numinb[bnum] * numperneedle; lnum < 256; lnum++) {
		printf("%4d ", lnum*4 + offset[bnum]);
		numchans++;
		numfillchans++;
		if ( numchans % 8 == 0 ){
		    printf("\n");
		}
	    }
	}
	printf("Wrote %d channels of end fill\n", numfillchans) > "/dev/tty";
    }
    
    printf("For a total of %d channels\n", numchans) > "/dev/tty";
    printf("\n");

}


